[nautilus-actions] NAExtension is renamed to FMAExtension



commit cb16660c28e7357184bee4a1437d6863a477855b
Author: Pierre Wieser <pwieser trychlos org>
Date:   Mon Sep 7 21:47:41 2015 +0200

    NAExtension is renamed to FMAExtension

 src/api/Makefile.am                         |    2 +-
 src/api/README                              |    2 +-
 src/api/{na-extension.h => fma-extension.h} |   36 +++++++++++++-------------
 src/core/na-module.c                        |   12 ++++----
 src/io-desktop/nadp-module.c                |   30 +++++++++++-----------
 src/io-gconf/nagp-module.c                  |   30 +++++++++++-----------
 src/io-xml/naxml-module.c                   |   30 +++++++++++-----------
 7 files changed, 71 insertions(+), 71 deletions(-)
---
diff --git a/src/api/Makefile.am b/src/api/Makefile.am
index 376d56c..df3805d 100644
--- a/src/api/Makefile.am
+++ b/src/api/Makefile.am
@@ -28,7 +28,7 @@
 api_includedir = $(pkgincludedir)
 
 api_include_HEADERS = \
-       na-extension.h                                                                          \
+       fma-extension.h                                                                         \
        \
        fma-dbus.h                                                                                      \
        na-iexporter.h                                                                          \
diff --git a/src/api/README b/src/api/README
index a6adf94..5e215f4 100644
--- a/src/api/README
+++ b/src/api/README
@@ -3,7 +3,7 @@ src/api
 This is the FileManager-Actions extension interface.
 
 Each extension library should at least implement the interface defined
-in na-extension.h.
+in fma-extension.h.
 
 Headers are installed as part of a development environment of such an
 extension. They are to be included by the extension as
diff --git a/src/api/na-extension.h b/src/api/fma-extension.h
similarity index 91%
rename from src/api/na-extension.h
rename to src/api/fma-extension.h
index 7624889..7696292 100644
--- a/src/api/na-extension.h
+++ b/src/api/fma-extension.h
@@ -27,14 +27,14 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __FILE_MANAGER_ACTIONS_API_NA_EXTENSION_H__
-#define __FILE_MANAGER_ACTIONS_API_NA_EXTENSION_H__
+#ifndef __FILE_MANAGER_ACTIONS_API_EXTENSION_H__
+#define __FILE_MANAGER_ACTIONS_API_EXTENSION_H__
 
 /**
  * SECTION: extension
  * @title: Plugins
  * @short_description: The FileManager-Actions Extension Interface Definition v 1
- * @include: file-manager-actions/na-extension.h
+ * @include: file-manager-actions/fma-extension.h
  *
  * &prodname; accepts extensions as dynamically loadable libraries
  * (aka plugins).
@@ -152,7 +152,7 @@
 G_BEGIN_DECLS
 
 /**
- * na_extension_startup:
+ * fma_extension_startup:
  * @module: the #GTypeModule of the plugin library being loaded.
  *
  * This function is called by the FileManager-Actions plugin manager when
@@ -168,7 +168,7 @@ G_BEGIN_DECLS
  *     static GType st_module_type = 0;
  *
  *     gboolean
- *     na_extension_startup( GTypeModule *plugin )
+ *     fma_extension_startup( GTypeModule *plugin )
  *     {
  *         static GTypeInfo info = {
  *             sizeof( NadpDesktopProviderClass ),
@@ -202,10 +202,10 @@ G_BEGIN_DECLS
  *
  * Since: 2.30
  */
-gboolean na_extension_startup    ( GTypeModule *module );
+gboolean fma_extension_startup    ( GTypeModule *module );
 
 /**
- * na_extension_get_version:
+ * fma_extension_get_version:
  *
  * This function is called by the &prodname; program each time
  * it needs to know which version of this API the plugin
@@ -219,15 +219,15 @@ gboolean na_extension_startup    ( GTypeModule *module );
  *
  * Since: 2.30
  */
-guint    na_extension_get_version( void );
+guint    fma_extension_get_version( void );
 
 /**
- * na_extension_list_types:
+ * fma_extension_list_types:
  * @types: the address where to store the zero-terminated array of
  *  instantiable #GType types this library implements.
  *
  * Returned #GType types must already have been registered in the
  * #GType system (e.g. at #na_extension_startup() time), and the objects
  * they describe may implement one or more of the interfaces defined in
  * this FileManager-Actions public API.
  *
@@ -242,18 +242,18 @@ guint    na_extension_get_version( void );
  *   <programlisting>
  *     &lcomment; the count of GType types provided by this extension
  *      * each new GType type must
  *      * - be registered in na_extension_startup()
  *      * - be addressed in na_extension_list_types().
  *      &rcomment;
  *     #define NADP_TYPES_COUNT    1
  *
  *     guint
- *     na_extension_list_types( const GType **types )
+ *     fma_extension_list_types( const GType **types )
  *     {
  *          static GType types_list [1+NADP_TYPES_COUNT];
  *
  *          &lcomment; NADP_TYPE_DESKTOP_PROVIDER has been previously
  *           * registered in na_extension_startup function
  *           &rcomment;
  *          types_list[0] = NADP_TYPE_DESKTOP_PROVIDER;
  *
@@ -270,10 +270,10 @@ guint    na_extension_get_version( void );
  *
  * Since: 2.30
  */
-guint    na_extension_list_types ( const GType **types );
+guint    fma_extension_list_types ( const GType **types );
 
 /**
- * na_extension_shutdown:
+ * fma_extension_shutdown:
  *
  * This function is called by FileManager-Actions when it is about to
  * shutdown itself.
@@ -287,8 +287,8 @@ guint    na_extension_list_types ( const GType **types );
  *
  * Since: 2.30
  */
-void     na_extension_shutdown   ( void );
+void     fma_extension_shutdown   ( void );
 
 G_END_DECLS
 
-#endif /* __FILE_MANAGER_ACTIONS_API_NA_EXTENSION_H__ */
+#endif /* __FILE_MANAGER_ACTIONS_API_EXTENSION_H__ */
@@ -219,15 +219,15 @@ gboolean na_extension_startup    ( GTypeModule *module );
  *
  * Returned #GType types must already have been registered in the
- * #GType system (e.g. at #na_extension_startup() time), and the objects
+ * #GType system (e.g. at #fma_extension_startup() time), and the objects
  * they describe may implement one or more of the interfaces defined in
  * this FileManager-Actions public API.
@@ -242,18 +242,18 @@ guint    na_extension_get_version( void );
  *     &lcomment; the count of GType types provided by this extension
  *      * each new GType type must
- *      * - be registered in na_extension_startup()
- *      * - be addressed in na_extension_list_types().
+ *      * - be registered in fma_extension_startup()
+ *      * - be addressed in fma_extension_list_types().
  *      &rcomment;
  *     #define NADP_TYPES_COUNT    1
@@ -242,18 +242,18 @@ guint    na_extension_get_version( void );
  *
  *          &lcomment; NADP_TYPE_DESKTOP_PROVIDER has been previously
- *           * registered in na_extension_startup function
+ *           * registered in fma_extension_startup function
  *           &rcomment;
  *          types_list[0] = NADP_TYPE_DESKTOP_PROVIDER;
diff --git a/src/core/na-module.c b/src/core/na-module.c
index b25538f..9707ee2 100644
--- a/src/core/na-module.c
+++ b/src/core/na-module.c
@@ -333,9 +333,9 @@ on_module_load( GTypeModule *gmodule )
  * if ok, we ask the plugin to initialize itself
  *
  * As of API v 1:
- * - na_extension_startup, na_extension_list_types and na_extension_shutdown
+ * - fma_extension_startup, na_extension_list_types and na_extension_shutdown
  *   are mandatory, and MUST be implemented by the plugin
  * - na_extension_get_version is optional, and defaults to 1.
  */
 static gboolean
 is_a_na_plugin( NAModule *module )
@@ -344,9 +344,9 @@ is_a_na_plugin( NAModule *module )
        gboolean ok;
 
        ok =
-               plugin_check( module, "na_extension_startup"    , ( gpointer * ) &module->private->startup) &&
-               plugin_check( module, "na_extension_list_types" , ( gpointer * ) &module->private->list_types 
) &&
-               plugin_check( module, "na_extension_shutdown"   , ( gpointer * ) &module->private->shutdown ) 
&&
+               plugin_check( module, "fma_extension_startup"    , ( gpointer * ) &module->private->startup) 
&&
+               plugin_check( module, "fma_extension_list_types" , ( gpointer * ) 
&module->private->list_types ) &&
+               plugin_check( module, "fma_extension_shutdown"   , ( gpointer * ) &module->private->shutdown 
) &&
                module->private->startup( G_TYPE_MODULE( module ));
 
        if( ok ){
@@ -372,7 +372,7 @@ plugin_check( NAModule *module, const gchar *symbol, gpointer *pfn )
 }
 
 /*
  * The 'na_extension_startup' function of the plugin has been already
  * called ; the GType types the plugin provides have so already been
  * registered in the GType system
  *
@@ -333,9 +333,9 @@ on_module_load( GTypeModule *gmodule )
  *   are mandatory, and MUST be implemented by the plugin
- * - na_extension_get_version is optional, and defaults to 1.
+ * - fma_extension_get_version is optional, and defaults to 1.
  */
 static gboolean
@@ -372,7 +372,7 @@ plugin_check( NAModule *module, const gchar *symbol, gpointer *pfn )
 
 /*
- * The 'na_extension_startup' function of the plugin has been already
+ * The 'fma_extension_startup' function of the plugin has been already
  * called ; the GType types the plugin provides have so already been
  * registered in the GType system
diff --git a/src/io-desktop/nadp-module.c b/src/io-desktop/nadp-module.c
index cfab226..43ee985 100644
--- a/src/io-desktop/nadp-module.c
+++ b/src/io-desktop/nadp-module.c
@@ -31,26 +31,26 @@
 #include <config.h>
 #endif
 
-#include <api/na-extension.h>
+#include <api/fma-extension.h>
 
 #include "nadp-desktop-provider.h"
 
 /* the count of GType types provided by this extension
  * each new GType type must
  * - be registered in na_extension_startup()
  * - be addressed in na_extension_list_types().
  */
 #define NADP_TYPES_COUNT       1
 
 /*
- * na_extension_startup:
+ * fma_extension_startup:
  *
  * mandatory starting with API v. 1.
  */
 gboolean
-na_extension_startup( GTypeModule *module )
+fma_extension_startup( GTypeModule *module )
 {
-       static const gchar *thisfn = "nadp_module_na_extension_startup";
+       static const gchar *thisfn = "nadp_module_fma_extension_startup";
 
        g_debug( "%s: module=%p", thisfn, ( void * ) module );
 
@@ -60,14 +60,14 @@ na_extension_startup( GTypeModule *module )
 }
 
 /*
- * na_extension_get_version:
+ * fma_extension_get_version:
  *
  * optional, defaults to 1.
  */
 guint
-na_extension_get_version( void )
+fma_extension_get_version( void )
 {
-       static const gchar *thisfn = "nadp_module_na_extension_get_version";
+       static const gchar *thisfn = "nadp_module_fma_extension_get_version";
        guint version;
 
        version = 1;
@@ -78,14 +78,14 @@ na_extension_get_version( void )
 }
 
 /*
- * na_extension_list_types:
+ * fma_extension_list_types:
  *
  * mandatory starting with v. 1.
  */
 guint
-na_extension_list_types( const GType **types )
+fma_extension_list_types( const GType **types )
 {
-       static const gchar *thisfn = "nadp_module_na_extension_list_types";
+       static const gchar *thisfn = "nadp_module_fma_extension_list_types";
        static GType types_list [1+NADP_TYPES_COUNT];
 
        g_debug( "%s: types=%p", thisfn, ( void * ) types );
@@ -99,14 +99,14 @@ na_extension_list_types( const GType **types )
 }
 
 /*
- * na_extension_shutdown:
+ * fma_extension_shutdown:
  *
  * mandatory starting with v. 1.
  */
 void
-na_extension_shutdown( void )
+fma_extension_shutdown( void )
 {
-       static const gchar *thisfn = "nadp_module_na_extension_shutdown";
+       static const gchar *thisfn = "nadp_module_fma_extension_shutdown";
 
        g_debug( "%s", thisfn );
 }
@@ -31,26 +31,26 @@
 /* the count of GType types provided by this extension
  * each new GType type must
- * - be registered in na_extension_startup()
- * - be addressed in na_extension_list_types().
+ * - be registered in fma_extension_startup()
+ * - be addressed in fma_extension_list_types().
  */
 #define NADP_TYPES_COUNT       1
diff --git a/src/io-gconf/nagp-module.c b/src/io-gconf/nagp-module.c
index 6236d7e..fbe7e11 100644
--- a/src/io-gconf/nagp-module.c
+++ b/src/io-gconf/nagp-module.c
@@ -31,26 +31,26 @@
 #include <config.h>
 #endif
 
-#include <api/na-extension.h>
+#include <api/fma-extension.h>
 
 #include "nagp-gconf-provider.h"
 
 /* the count of GType types provided by this extension
  * each new GType type must
  * - be registered in na_extension_startup()
  * - be addressed in na_extension_list_types().
  */
 #define NAGP_TYPES_COUNT       1
 
 /*
- * na_extension_startup:
+ * fma_extension_startup:
  *
  * mandatory starting with API v. 1.
  */
 gboolean
-na_extension_startup( GTypeModule *module )
+fma_extension_startup( GTypeModule *module )
 {
-       static const gchar *thisfn = "nagp_module_na_extension_startup";
+       static const gchar *thisfn = "nagp_module_fma_extension_startup";
 
        g_debug( "%s: module=%p", thisfn, ( void * ) module );
 
@@ -60,14 +60,14 @@ na_extension_startup( GTypeModule *module )
 }
 
 /*
- * na_extension_get_version:
+ * fma_extension_get_version:
  *
  * optional, defaults to 1.
  */
 guint
-na_extension_get_version( void )
+fma_extension_get_version( void )
 {
-       static const gchar *thisfn = "nagp_module_na_extension_get_version";
+       static const gchar *thisfn = "nagp_module_fma_extension_get_version";
        guint version;
 
        version = 1;
@@ -78,14 +78,14 @@ na_extension_get_version( void )
 }
 
 /*
- * na_extension_list_types:
+ * fma_extension_list_types:
  *
  * mandatory starting with v. 1.
  */
 guint
-na_extension_list_types( const GType **types )
+fma_extension_list_types( const GType **types )
 {
-       static const gchar *thisfn = "nagp_module_na_extension_list_types";
+       static const gchar *thisfn = "nagp_module_fma_extension_list_types";
        static GType types_list [1+NAGP_TYPES_COUNT];
 
        g_debug( "%s: types=%p", thisfn, ( void * ) types );
@@ -99,14 +99,14 @@ na_extension_list_types( const GType **types )
 }
 
 /*
- * na_extension_shutdown:
+ * fma_extension_shutdown:
  *
  * mandatory starting with v. 1.
  */
 void
-na_extension_shutdown( void )
+fma_extension_shutdown( void )
 {
-       static const gchar *thisfn = "nagp_module_na_extension_shutdown";
+       static const gchar *thisfn = "nagp_module_fma_extension_shutdown";
 
        g_debug( "%s", thisfn );
 }
@@ -31,26 +31,26 @@
 /* the count of GType types provided by this extension
  * each new GType type must
- * - be registered in na_extension_startup()
- * - be addressed in na_extension_list_types().
+ * - be registered in fma_extension_startup()
+ * - be addressed in fma_extension_list_types().
  */
 #define NAGP_TYPES_COUNT       1
diff --git a/src/io-xml/naxml-module.c b/src/io-xml/naxml-module.c
index 50b6126..4cd1fb5 100644
--- a/src/io-xml/naxml-module.c
+++ b/src/io-xml/naxml-module.c
@@ -31,26 +31,26 @@
 #include <config.h>
 #endif
 
-#include <api/na-extension.h>
+#include <api/fma-extension.h>
 
 #include "naxml-provider.h"
 
 /* the count of GType types provided by this extension
  * each new GType type must
  * - be registered in na_extension_startup()
  * - be addressed in na_extension_list_types().
  */
 #define NAXML_TYPES_COUNT      1
 
 /*
- * na_extension_startup:
+ * fma_extension_startup:
  *
  * mandatory starting with API v. 1.
  */
 gboolean
-na_extension_startup( GTypeModule *module )
+fma_extension_startup( GTypeModule *module )
 {
-       static const gchar *thisfn = "naxml_module_na_extension_startup";
+       static const gchar *thisfn = "naxml_module_fma_extension_startup";
 
        g_debug( "%s: module=%p", thisfn, ( void * ) module );
 
@@ -60,14 +60,14 @@ na_extension_startup( GTypeModule *module )
 }
 
 /*
- * na_extension_get_version:
+ * fma_extension_get_version:
  *
  * optional, defaults to 1.
  */
 guint
-na_extension_get_version( void )
+fma_extension_get_version( void )
 {
-       static const gchar *thisfn = "naxml_module_na_extension_get_version";
+       static const gchar *thisfn = "naxml_module_fma_extension_get_version";
        guint version;
 
        version = 1;
@@ -78,14 +78,14 @@ na_extension_get_version( void )
 }
 
 /*
- * na_extension_list_types:
+ * fma_extension_list_types:
  *
  * mandatory starting with v. 1.
  */
 guint
-na_extension_list_types( const GType **types )
+fma_extension_list_types( const GType **types )
 {
-       static const gchar *thisfn = "naxml_module_na_extension_list_types";
+       static const gchar *thisfn = "naxml_module_fma_extension_list_types";
        static GType types_list [1+NAXML_TYPES_COUNT];
 
        g_debug( "%s: types=%p", thisfn, ( void * ) types );
@@ -99,14 +99,14 @@ na_extension_list_types( const GType **types )
 }
 
 /*
- * na_extension_shutdown:
+ * fma_extension_shutdown:
  *
  * mandatory starting with v. 1.
  */
 void
-na_extension_shutdown( void )
+fma_extension_shutdown( void )
 {
-       static const gchar *thisfn = "naxml_module_na_extension_shutdown";
+       static const gchar *thisfn = "naxml_module_fma_extension_shutdown";
 
        g_debug( "%s", thisfn );
 }
@@ -31,26 +31,26 @@
 /* the count of GType types provided by this extension
  * each new GType type must
- * - be registered in na_extension_startup()
- * - be addressed in na_extension_list_types().
+ * - be registered in fma_extension_startup()
+ * - be addressed in fma_extension_list_types().
  */
 #define NAXML_TYPES_COUNT      1


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]